@@ -1,10 +1,8 @@
-/* $Id: dialer.c,v 1.17 2011-02-09 21:26:43 rousseau Exp $ */
-
 /*******************************************************************************
  * dialer.c
  * A module of J-Pilot http://jpilot.org
  *
- * Copyright (C) 1999-2002 by Judd Montgomery
+ * Copyright (C) 1999-2014 by Judd Montgomery
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -162,7 +160,9 @@ static void dialer(gpointer data, int phone_or_ext)
    command[1022]='\0';
 
    jp_logf(JP_LOG_STDOUT|JP_LOG_FILE, _("executing command = [%s]\n"), command);
-   system(command);
+   if (system(command) == -1) {
+      jp_logf(JP_LOG_WARN, "system call failed %s %d\n", __FILE__, __LINE__);
+   }
 }
 
 static void cb_dial_ext(GtkWidget *widget, gpointer data)
