@@ -1,10 +1,8 @@
-/* $Id: export_gui.c,v 1.28 2010-10-15 23:50:07 rikster5 Exp $ */
-
 /*******************************************************************************
  * export_gui.c
  * A module of J-Pilot http://jpilot.org
  *
- * Copyright (C) 1999-2002 by Judd Montgomery
+ * Copyright (C) 1999-2014 by Judd Montgomery
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -116,7 +114,9 @@ int export_browse(GtkWidget *main_window, int pref_export)
          }
       }
 
-      chdir(dir);
+      if (chdir(dir)<0) {
+         jp_logf(JP_LOG_WARN, "chdir failed %s %d\n", __FILE__, __LINE__);
+      }
    }
    filesel = gtk_file_selection_new(_("File Browser"));
 
