@@ -1,10 +1,8 @@
-/* $Id: import_gui.c,v 1.33 2010-10-15 23:50:07 rikster5 Exp $ */
-
 /*******************************************************************************
  * import_gui.c
  * A module of J-Pilot http://jpilot.org
  *
- * Copyright (C) 1999-2002 by Judd Montgomery
+ * Copyright (C) 1999-2014 by Judd Montgomery
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -140,7 +138,9 @@ static int guess_file_type(const char *path)
       return IMPORT_TYPE_DAT;
    }
    fseek(in, 0, SEEK_SET);
-   fread(text, 1, 15, in);
+   if (fread(text, 1, 15, in) < 1) {
+      jp_logf(JP_LOG_WARN, "fread failed %s %d\n", __FILE__, __LINE__);
+   }
    if (!strncmp(text, "CSV ", 4)) {
       fclose(in);
       return IMPORT_TYPE_CSV;
