@@ -1,10 +1,8 @@
-/* $Id: jpilot.c,v 1.195 2011-04-06 12:58:50 rousseau Exp $ */
-
 /*******************************************************************************
  * jpilot.c
  * A module of J-Pilot http://jpilot.org
  *
- * Copyright (C) 1999-2003 by Judd Montgomery
+ * Copyright (C) 1999-2014 by Judd Montgomery
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -919,7 +917,9 @@ static void cb_read_pipe_from_child(gpointer data,
                } else {
                   sprintf(command_str, "%d:\n", PIPE_SYNC_CANCEL);
                }
-               write(pipe_to_child, command_str, strlen(command_str));
+               if (write(pipe_to_child, command_str, strlen(command_str)) < 0) {
+                  jp_logf(JP_LOG_WARN, "write failed %s %d\n", __FILE__, __LINE__);
+               }
                fsync(pipe_to_child);
             }
             break;
@@ -1036,7 +1036,9 @@ static void cb_web(GtkWidget *widget, gpointer data)
 
    sel=GPOINTER_TO_INT(data);
    jp_logf(JP_LOG_INFO, PN": executing %s\n", url_commands[sel].command);
-   system(url_commands[sel].command);
+   if (system(url_commands[sel].command) == -1) {
+      jp_logf(JP_LOG_WARN, "system call failed %s %d\n", __FILE__, __LINE__);
+   }
 }
 
 #endif
@@ -1080,7 +1082,7 @@ static guint8 *get_inline_pixbuf_data(const char **xpm_icon_data,
        gdk_pixbuf_get_height(pixbuf) != icon_size) {
       scaled_pb = gdk_pixbuf_scale_simple(pixbuf, icon_size, icon_size,
                                           GDK_INTERP_BILINEAR);
-      gdk_pixbuf_unref(pixbuf);
+      g_object_unref(pixbuf);
       pixbuf = scaled_pb;
    }
 
@@ -1088,7 +1090,7 @@ static guint8 *get_inline_pixbuf_data(const char **xpm_icon_data,
    gdk_pixdata_from_pixbuf(pixdata, pixbuf, FALSE);
    data = gdk_pixdata_serialize(pixdata, &len);
 
-   gdk_pixbuf_unref(pixbuf);
+   g_object_unref(pixbuf);
    g_free(pixdata);
 
    return data;
