@@ -1,10 +1,8 @@
-/* $Id: memo_gui.c,v 1.151 2011-12-22 03:43:07 judd Exp $ */
-
 /*******************************************************************************
  * memo_gui.c
  * A module of J-Pilot http://jpilot.org
  *
- * Copyright (C) 1999-2002 by Judd Montgomery
+ * Copyright (C) 1999-2014 by Judd Montgomery
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -293,7 +291,9 @@ static int cb_memo_import(GtkWidget *parent_window,
       text[0]='\0';
       while (!feof(in)) {
          line[0]='\0';
-         fgets(line, 255, in);
+         if (fgets(line, 255, in) == NULL) {
+            jp_logf(JP_LOG_WARN, "write failed %s %d\n", __FILE__, __LINE__);
+         }
          line[255] = '\0';
          len=strlen(line);
          if (text_len+len>65534) {
@@ -335,7 +335,9 @@ static int cb_memo_import(GtkWidget *parent_window,
    if (type==IMPORT_TYPE_CSV) {
       jp_logf(JP_LOG_DEBUG, "Memo import CSV [%s]\n", file_path);
       /* Get the first line containing the format and check for reasonableness */
-      fgets(text, sizeof(text), in);
+      if (fgets(text, sizeof(text), in) == NULL) {
+         jp_logf(JP_LOG_WARN, "fgets failed %s %d\n", __FILE__, __LINE__);
+      }
       ret = verify_csv_header(text, NUM_MEMO_CSV_FIELDS, file_path);
       if (EXIT_FAILURE == ret) return EXIT_FAILURE;
 
@@ -512,6 +514,8 @@ static void cb_memo_export_ok(GtkWidget *export_window, GtkWidget *clist,
    char csv_text[65550];
    long char_set;
    char *utf;
+   int cat;
+   int j;
 
    /* Open file for export, including corner cases where file exists or 
     * can't be opened */
@@ -574,6 +578,15 @@ static void cb_memo_export_ok(GtkWidget *export_window, GtkWidget *clist,
       fprintf(out, "Note,Folder\n");
    }
 
+   /* Write a header to the KeePassX XML file */
+   if (type == EXPORT_TYPE_KEEPASSX) {
+      fprintf(out, "<!DOCTYPE KEEPASSX_DATABASE>\n");
+      fprintf(out, "<database>\n");
+      fprintf(out, " <group>\n");
+      fprintf(out, "  <title>Memos</title>\n");
+      fprintf(out, "  <icon>7</icon>\n");
+   }
+
    get_pref(PREF_CHAR_SET, &char_set, NULL);
    list=GTK_CLIST(clist)->selection;
 
@@ -612,7 +625,7 @@ static void cb_memo_export_ok(GtkWidget *export_window, GtkWidget *clist,
          utf = charset_p2newj(memo_app_info.category.name[mmemo->attrib & 0x0F], 16, char_set);
          str_to_csv_str(csv_text, utf);
          fprintf(out, "\"Memos > %s\"\n", csv_text);
-         printf("\"Memos > %s\"\n", utf, csv_text);
+         printf("\"Memos > %s\"\n", utf);
          g_free(utf);
          break;
 
@@ -636,11 +649,77 @@ static void cb_memo_export_ok(GtkWidget *export_window, GtkWidget *clist,
          fprintf(out, _("\n----- End of Memo -----\n\n"));
          break;
 
+       case EXPORT_TYPE_KEEPASSX:
+	 break;
+
        default:
          jp_logf(JP_LOG_WARN, _("Unknown export type\n"));
       }
    }
 
+   /* I'm writing a second loop for the KeePassX XML file because I want to
+    * put each category into a folder and we need to write the tag for a folder
+    * and then find each record in that category/folder
+    */
+   if (type==EXPORT_TYPE_KEEPASSX) {
+      for (cat=0; cat < 16; cat++) {
+	 if (memo_app_info.category.name[cat][0]=='\0') {
+	    continue;
+	 }
+	 /* Write a folder XML tag */
+         utf = charset_p2newj(memo_app_info.category.name[cat], 16, char_set);
+         fprintf(out, "  <group>\n");
+	 fprintf(out, "   <title>%s</title>\n", utf);
+	 fprintf(out, "   <icon>7</icon>\n");
+	 g_free(utf);
+	 for (i=0, temp_list=list; temp_list; temp_list = temp_list->next, i++) {
+	    mmemo = gtk_clist_get_row_data(GTK_CLIST(clist), GPOINTER_TO_INT(temp_list->data));
+	    if (!mmemo) {
+	       continue;
+	       jp_logf(JP_LOG_WARN, _("Can't export memo %d\n"), (long) temp_list->data + 1);
+	    }
+	    if ((mmemo->attrib & 0x0F) != cat) {
+	       continue;
+	    }
+	    fprintf(out, "   <entry>\n");
+	    
+	    /* Create a title (which is the first line of the memo) */
+	    for (j=0; j<100; j++) {
+	       str1[j]=mmemo->memo.text[j];
+	       if (str1[j] == '\0') {
+		  break;
+	       }
+	       if (str1[j] == '\n') {
+		  str1[j]='\0';
+		  break;
+	       }
+	    }
+	    str1[100]='\0';
+	    str_to_keepass_str(csv_text, str1);
+	    fprintf(out, "    <title>%s</title>\n", csv_text);
+	    /* No keyring field for username */
+	    /* No keyring field for password */
+	    /* No keyring field for url */
+	    str_to_keepass_str(csv_text, mmemo->memo.text);
+	    fprintf(out, "    <comment>%s</comment>\n", csv_text);
+	    fprintf(out, "    <icon>7</icon>\n");
+	    /* No keyring field for creation */
+	    /* No keyring field for lastaccess */
+	    /* No keyring field for lastmod */
+	    /* No keyring field for expire */
+	    fprintf(out, "    <expire>Never</expire>\n");
+	    fprintf(out, "   </entry>\n");
+	 }
+	 fprintf(out, "  </group>\n");
+      }
+
+      /* Write a footer to the KeePassX XML file */
+      if (type == EXPORT_TYPE_KEEPASSX) {
+	 fprintf(out, " </group>\n");
+	 fprintf(out, "</database>\n");
+      }
+   }
+
    if (out) {
       fclose(out);
    }
@@ -665,9 +744,10 @@ int memo_export(GtkWidget *window)
    int w, h, x, y;
    char *type_text[]={N_("Text"), 
                       N_("CSV"), 
-                      N_("B-Folders CSV"), 
+                      N_("B-Folders CSV"),
+                      N_("KeePassX XML"),
                       NULL};
-   int type_int[]={EXPORT_TYPE_TEXT, EXPORT_TYPE_CSV, EXPORT_TYPE_BFOLDERS};
+   int type_int[]={EXPORT_TYPE_TEXT, EXPORT_TYPE_CSV, EXPORT_TYPE_BFOLDERS, EXPORT_TYPE_KEEPASSX};
 
    gdk_window_get_size(window->window, &w, &h);
    gdk_window_get_root_origin(window->window, &x, &y);
@@ -1264,10 +1344,7 @@ static gboolean cb_key_pressed_right_side(GtkWidget   *widget,
       g_snprintf(command, sizeof(command), "%s %s", ext_editor, tmp_fname);
 
       /* jp_logf(JP_LOG_STDOUT|JP_LOG_FILE, _("executing command = [%s]\n"), command); */
-      int r = system(command);
-      
-      if (!r)
-      {
+      if (system(command) == -1) {
          /* Read data back from temporary file into memo */
          char text_in[0xFFFF];
          size_t bytes_read;
