@@ -1,10 +1,8 @@
-/* $Id: prefs.c,v 1.91 2011-04-06 12:43:45 rousseau Exp $ */
-
 /*******************************************************************************
  * prefs.c
  * A module of J-Pilot http://jpilot.org
  *
- * Copyright (C) 1999-2002 by Judd Montgomery
+ * Copyright (C) 1999-2014 by Judd Montgomery
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -882,7 +880,9 @@ int jp_pref_read_rc_file(char *filename, prefType prefs[], int num_prefs)
    }
 
    while (!feof(in)) {
-      fgets(line, sizeof(line), in);
+      if (fgets(line, sizeof(line), in) == NULL) {
+         ; /* Keep compiler from complaining */
+      }
       if (feof(in)) break;
       line[sizeof(line)-2] = ' ';
       line[sizeof(line)-1] = '\0';
