@@ -1,10 +1,8 @@
-/* $Id: todo.c,v 1.54 2010-10-16 22:49:25 rikster5 Exp $ */
-
 /*******************************************************************************
  * todo.c
  * A module of J-Pilot http://jpilot.org
  *
- * Copyright (C) 1999-2002 by Judd Montgomery
+ * Copyright (C) 1999-2014 by Judd Montgomery
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -77,7 +75,7 @@ int get_todo_app_info(struct ToDoAppInfo *ai)
 #ifdef ENABLE_MANANA
    get_pref(PREF_MANANA_MODE, &ivalue, NULL);
    if (ivalue) {
-      strcpy(DBname, "MaanaDB");
+      strcpy(DBname, "MananaDB");
    } else {
       strcpy(DBname, "ToDoDB");
    }
@@ -164,7 +162,7 @@ int get_todos2(ToDoList **todo_list, int sort_order,
 #ifdef ENABLE_MANANA
    get_pref(PREF_MANANA_MODE, &ivalue, NULL);
    if (ivalue) {
-      num = jp_read_DB_files("MaanaDB", &records);
+      num = jp_read_DB_files("MananaDB", &records);
       if (-1 == num)
          return 0;
    } else {
@@ -317,7 +315,7 @@ int pc_todo_write(struct ToDo *todo, PCRecType rt, unsigned char attrib,
 #ifdef ENABLE_MANANA
    get_pref(PREF_MANANA_MODE, &ivalue, NULL);
    if (ivalue) {
-      jp_pc_write("MaanaDB", &br);
+      jp_pc_write("MananaDB", &br);
    } else {
       jp_pc_write("ToDoDB", &br);
    }
