@@ -1,10 +1,8 @@
-/* $Id: todo_gui.c,v 1.183 2011-04-06 12:47:09 rousseau Exp $ */
-
 /*******************************************************************************
  * todo_gui.c
  * A module of J-Pilot http://jpilot.org
  *
- * Copyright (C) 1999-2002 by Judd Montgomery
+ * Copyright (C) 1999-2014 by Judd Montgomery
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -421,7 +419,9 @@ static int cb_todo_import(GtkWidget *parent_window,
    if (type==IMPORT_TYPE_CSV) {
       jp_logf(JP_LOG_DEBUG, "Todo import CSV [%s]\n", file_path);
       /* Get the first line containing the format and check for reasonableness */
-      fgets(text, sizeof(text), in);
+      if (fgets(text, sizeof(text), in) == NULL) {
+         jp_logf(JP_LOG_WARN, "fgets failed %s %d\n", __FILE__, __LINE__);
+      }
       ret = verify_csv_header(text, NUM_TODO_CSV_FIELDS, file_path);
       if (EXIT_FAILURE == ret) return EXIT_FAILURE;
 
@@ -1046,8 +1046,8 @@ static void cb_edit_cats(GtkWidget *widget, gpointer data)
 #ifdef ENABLE_MANANA
    get_pref(PREF_MANANA_MODE, &ivalue, NULL);
    if (ivalue) {
-      strcpy(pdb_name, "MaanaDB.pdb");
-      strcpy(db_name, "MaanaDB");
+      strcpy(pdb_name, "MananaDB.pdb");
+      strcpy(db_name, "MananaDB");
    } else {
       strcpy(pdb_name, "ToDoDB.pdb");
       strcpy(db_name, "ToDoDB");
@@ -1733,10 +1733,7 @@ static gboolean cb_key_pressed_right_side(GtkWidget   *widget,
       g_snprintf(command, sizeof(command), "%s %s", ext_editor, tmp_fname);
 
       /* jp_logf(JP_LOG_STDOUT|JP_LOG_FILE, _("executing command = [%s]\n"), command); */
-      int r = system(command);
-      
-      if (!r)
-      {
+      if (system(command) == -1) {
          /* Read data back from temporary file into memo */
          char text_in[0xFFFF];
          size_t bytes_read;
