@@ -1,10 +1,8 @@
-/* $Id: utils.h,v 1.90 2011-12-22 00:46:37 judd Exp $ */
-
 /*******************************************************************************
  * utils.h
  * A module of J-Pilot http://jpilot.org
  * 
- * Copyright (C) 1999-2002 by Judd Montgomery
+ * Copyright (C) 1999-2014 by Judd Montgomery
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -140,6 +138,7 @@
 #define EXPORT_TYPE_ICALENDAR   106
 #define EXPORT_TYPE_LDIF        107
 #define EXPORT_TYPE_BFOLDERS    108
+#define EXPORT_TYPE_KEEPASSX    109
 
 /* DAT file types */
 #define DAT_DATEBOOK_FILE    10
@@ -376,6 +375,13 @@ void free_search_record_list(struct search_record **sr);
  * Return value is the number of chars written to dest. */
 int str_to_csv_str(char *dest, char *src);
 
+/*
+ * Copy src string into dest while escaping carriage returns with <br/>
+ * dest could be as long as strlen(src)*5.
+ * Return value is the number of chars written to dest.
+ */
+int str_to_keepass_str(char *dest, char *src);
+
 /* Copy src string into dest while escaping carriage returns,
  * backslashes, commas and semicolons.  Also do line wrapping.
  * dest could be as long as strlen(src) * 2 + strlen(src) / 30.
